@@ -13,7 +13,7 @@ use crate::{
         TsAsExpr, TsConstAssertion, TsNonNullExpr, TsTypeAnn, TsTypeAssertion, TsTypeParamDecl,
         TsTypeParamInstantiation,
     },
-    Invalid,
+    BigInt, Invalid,
 };
 use is_macro::Is;
 use serde::{self, Deserialize, Serialize};
@@ -951,6 +951,12 @@ impl From<Str> for Expr {
     }
 }
 
+impl From<BigInt> for Expr {
+    fn from(v: BigInt) -> Self {
+        Expr::Lit(Lit::BigInt(v))
+    }
+}
+
 #[ast_node("OptionalChainingExpression")]
 #[derive(Eq, Hash, EqIgnoreSpan)]
 #[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
